@@ -5,7 +5,7 @@ from typing import Iterable, NamedTuple
 
 
 AbstractSyntaxTree = ast.Module  # Should be module instead of ast
-FileContent = str
+FileContent = bytes
 Filename = str  # Contains full path to existing file
 Pathname = str  # Can contain wildewards
 
@@ -14,7 +14,8 @@ Pathname = str  # Can contain wildewards
 class Args:
     fix: bool = False
     verbose: bool = False
-    dry: Iterable[Pathname] = ()
+    dry: bool = False
+    only: Iterable[Pathname] = ()
     paths: Iterable[Pathname] = ()
     exclude: Iterable[Pathname] = ()
     ignore_definitions: Iterable[Pathname] = ()
